'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fileExists = require('file-exists');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var projectFolder = process.cwd();
var packageJsonPath = _path2.default.resolve(projectFolder, 'package.json');
var packageJson = (0, _fileExists.sync)(packageJsonPath) ? require(packageJsonPath) : {};
var pkgConfig = packageJson['babel-runner'] || {};

// Retrieve Paths for babelrc & node hooks from default locations or from package.json
var nodeHooksPath = function () {
  var filePath = pkgConfig.nodeHooks ? pkgConfig.nodeHooks : _path2.default.resolve(projectFolder, 'nodeHooks.js');
  return (0, _fileExists.sync)(filePath) ? filePath : null;
}();
var babelrc = function () {
  var defaultBabelrcJS = _path2.default.resolve(projectFolder, 'babelrc.js');
  var defaultBabelrcJson = _path2.default.resolve(projectFolder, '.babelrc');

  if ((0, _fileExists.sync)(defaultBabelrcJson)) {
    // No need to read the file, we can use babel-register's automatic `.babelrc`-finding "feature"
    return {};
  } else if ((0, _fileExists.sync)(defaultBabelrcJS)) {
    // We read a file which expects all presets & plugins to be resolved with `require.resolve`
    return require(defaultBabelrcJS);
  } else if (pkgConfig.babelrc && pkgConfig.babelrc.match('.js$') && (0, _fileExists.sync)(pkgConfig.babelrc)) {
    // Use the `babelrc.js`-file defined in package.json
    return require(pkgConfig.babelrc);
  }

  return null;
}();

// Run babel and include node-hooks
var babelRunner = function babelRunner() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      fileToRun = _ref.fileToRun;

  // Teach Node how to import other filetypes, such as .scss .jsx or .png
  if (nodeHooksPath) {
    require(nodeHooksPath);
  }

  // Teach Node how to use babel compilation, using explicitly specified babelrc
  if (babelrc) {
    require('babel-register')(babelrc);
  }

  if (fileToRun) {
    // rely on Node error if file doesn't exist
    require(_path2.default.resolve(process.cwd(), fileToRun));
  }
};

module.exports = babelRunner;
module.exports.default = babelRunner;
module.exports.babelrc = babelrc;